@@ -2,7 +2,6 @@ package My::DLL;
 
 use strict;
 use warnings;
-use 5.010;
 use autodie qw( :all );  # need IPC::System::Simple
 use Alien::TinyCC;
 use Archive::Ar 2.02;
@@ -15,7 +14,7 @@ use File::Copy qw( copy );
 use Path::Class::File ();
 use File::chdir;
 
-our @EXPORT = qw( tcc_clean tcc_build );
+our @EXPORT = qw( tcc_clean tcc_build tcc_name );
 
 my $share = Path::Class::File
   ->new(dirname $INC{'My/DLL.pm'})
@@ -28,20 +27,20 @@ my $log = $share->file('build.log')->opena;
 
 sub tcc_clean
 {
-  say $log "--- clean ", time, '---';
+  print $log "--- clean ", time, '---', "\n";
   for(grep { $_->basename =~ /^libtcc\./ } $share->children)
   {
-    say $log "unlink $_";
+    print $log "unlink $_", "\n";
     unlink $_;
   }
   if(-d $share->subdir('lib'))
   {
     for($share->subdir('lib')->children)
     {
-      say $log "unlink $_";
+      print $log "unlink $_", "\n";
       unlink $_;
     }
-    say $log "rmdir " . $share->subdir('lib');
+    print $log "rmdir " . $share->subdir('lib'), "\n";
     rmdir $share->subdir('lib');
   }
 }
@@ -50,7 +49,7 @@ sub tcc_build
 {
   tcc_clean();
   
-  say $log "--- build ", time, '---';
+  print $log "--- build ", time, '---', "\n";
 
   my $libdir = Path::Class::Dir->new(
     Alien::TinyCC->libtcc_library_path,
@@ -60,8 +59,8 @@ sub tcc_build
   {
     do {
       my $from = $libdir->file('libtcc.dll');
-      my $to   = $share->file('libtcc.dll');
-      say $log "copy $from => $to";
+      my $to   = tcc_name();
+      print $log "copy $from => $to", "\n";
       copy($from => $to)
       || die "unable to copy $from => $to $!";
     };
@@ -72,7 +71,7 @@ sub tcc_build
     {
       my $from = $file;
       my $to   = $share->file('lib', basename $file);
-      say $log "copy $from $to";
+      print $log "copy $from $to", "\n";
       copy($from => $to)
       || die "unable to copy $from => $to $!";
     }
@@ -80,12 +79,12 @@ sub tcc_build
   else
   {
     my $lib = $libdir->file('libtcc.a');
-    say $log "lib = $lib";
+    print $log "lib = $lib", "\n";
 
     die "unable to find libtcc.a" unless -f $lib;
 
     my $tmp = Path::Class::Dir->new(tempdir( CLEANUP => 1 ));
-    say $log "tmp = $tmp";
+    print $log "tmp = $tmp", "\n";
 
     do {
       local $CWD = $tmp;
@@ -101,10 +100,10 @@ sub tcc_build
       $ar->extract || die $ar->error;
     };
     my @obj = grep /\.(o|obj)$/, $tmp->children;
-    say $log "obj = $_" for @obj;
+    print $log "obj = $_", "\n" for @obj;
 
-    my @cmd = ($Config{cc}, '-o' => $share->file("libtcc.$Config{dlext}"), '-shared', @obj);
-    say $log "+ @cmd\n";
+    my @cmd = ($Config{cc}, '-o' => tcc_name(), '-shared', @obj);
+    print $log "+ @cmd\n";
 
     print "+ @cmd\n";
     system @cmd;
@@ -112,4 +111,9 @@ sub tcc_build
   }
 }
 
+sub tcc_name
+{
+  $^O eq 'MSWin32' ? $share->file('libtcc.dll') : $share->file("libtcc.$Config{dlext}");
+}
+
 1;
