@@ -10,7 +10,7 @@ use Carp qw( croak carp );
 use File::ShareDir ();
 
 # ABSTRACT: Tiny C Compiler for FFI
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 
 sub _dlext ()
@@ -220,6 +220,8 @@ sub detect_sysinclude_path
     croak "Cannot detect sysinclude path";
   }
   
+  croak "Cannot detect sysinclude path" unless grep { -d $_ } @path_list;
+  
   $self->add_sysinclude_path($_) for @path_list;
   
   @path_list;
@@ -371,7 +373,7 @@ FFI::TinyCC - Tiny C Compiler for FFI
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -598,19 +600,19 @@ This method is deprecated, and will be removed from a future version of
 L<FFI::TinyCC>, but not before January 31, 2017.  It will issue a 
 warning if you try to use it.  Instead of this:
 
- my $function = $ffi->get_ffi_raw($name, FFI::void);
+ my $function = $tcc->get_ffi_raw($name, FFI::void);
  $function->();
 
 Do this:
 
  use FFI::Raw;
- my $function = FFI::Raw->new_from_ptr($ffi->get_symbol($name), FFI::void);
+ my $function = FFI::Raw->new_from_ptr($tcc->get_symbol($name), FFI::void);
  $function->();
 
 Or better yet, use L<FFI::Platypus> instead:
 
  use FFI::Platypus::Declare;
- attach [$ffi->get_symbol($name) => 'function'] => [] => 'void';
+ attach [$tcc->get_symbol($name) => 'function'] => [] => 'void';
  function();
 
 =head1 EXAMPLES
@@ -707,6 +709,8 @@ with L<Alien::TinyCC>.
 
 =item L<FFI::Platypus>
 
+=item L<C::Blocks>
+
 =item L<Alien::TinyCC>
 
 =item L<C::TinyCompiler>
@@ -728,8 +732,6 @@ Copyright 2013 Steffen Muellero
 This program is free software; you can redistribute it and/or modify it 
 under the same terms as Perl itself.
 
-=cut
-
 =head1 AUTHOR
 
 Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
